import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis,
  sum,
  nest,
  format,
  timeFormat
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Total Salary in MLB from Season 13~16';
  
  const xValue = d => d.Season;
  const xAxisLabel = 'Season Year';
  
  const yValue = d => d.Salary;
  const circleRadius = 6;
  const yAxisLabel = 'Total Salary';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15)
	.tickFormat(timeFormat("%Y"));
  
  const yAxisTickFormat = number =>
    format('.3s')(number).replace('G', 'B');
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
  	.tickFormat(yAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g')
    .attr('transform', `translate(0,${innerHeight})`)
  .call(xAxis);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
    .curve(curveBasis);
  
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', lineGenerator(data));
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

  const groupData = data => {
      let groupDataBySeason = nest()
      .key(d => d.Season)
      .rollup(leaves => sum(leaves, d => d['Team Salary']))
      .entries(data);
      return groupDataBySeason.map(d => ({
      Season: new Date(d.key),
      Salary: d.value
    }));
  };

csv('https://vizhub.com/wangjonathan/datasets/MLB Team Stat 2013-2016.csv').then(data => {
  let result = groupData(data);
  console.log(result);
  render(result);
});
  